@@ -61,7 +61,10 @@ wrerr_handler(png_structp png, png_const_charp data)
 }
 
 
-static void null_png_handler(png_structp /*png*/, png_const_charp /*data*/) {}
+static void
+null_png_handler(png_structp /*png*/, png_const_charp /*data*/)
+{
+}
 
 
 
@@ -625,7 +628,7 @@ write_info(png_structp& sp, png_infop& ip, int& color_type, ImageSpec& spec,
         if (icc_profile && length)
             png_set_iCCP(sp, ip, "Embedded Profile", 0, icc_profile, length);
 #else
-        char* icc_profile      = (char*)icc_profile_parameter->data();
+        char* icc_profile = (char*)icc_profile_parameter->data();
         if (icc_profile && length)
             png_set_iCCP(sp, ip, (png_charp) "Embedded Profile", 0, icc_profile,
                          length);
